==> ConsoleEngine-0.0.1.crate: ConsoleEngine-0.0.1/src/lib.rs <==
pub mod console {
    use std::{io, thread, time};

    pub struct Console {}

    impl Console {
        pub fn new() -> Console {
            Console {}
        }

        pub fn print<T>(&self, message: T, settings: Settings)
        where
            T: std::string::ToString,
        {
            for c in message.to_string().chars() {
                print!(
                    "{}{}{}{}",
                    settings.color.get_text_code(),
                    settings.background_color.get_bg_code(),
                    c,
                    Color::Clear.get_text_code()
                );
                io::Write::flush(&mut std::io::stdout()).unwrap();
                thread::sleep(settings.speed);
            }
        }

        pub fn print_line<T>(&self, message: T, settings: Settings)
        where
            T: std::string::ToString,
        {
            for c in message.to_string().chars() {
                print!(
                    "{}{}{}{}",
                    settings.color.get_text_code(),
                    settings.background_color.get_bg_code(),
                    c,
                    Color::Clear.get_text_code()
                );
                io::Write::flush(&mut std::io::stdout()).unwrap();
                thread::sleep(settings.speed);
            }

            println!();
        }

        // gets input without new line from the console
        pub fn get_input(&self) -> String {
            let mut input = String::new();
            io::stdin()
                .read_line(&mut input)
                .expect("Error while getting input from operating system");
            input = String::from(input.trim());
            input
        }

        // gets input without new line from the console with custom message and settings
        pub fn get_custom_input<T>(&self, message: T, settings: Settings) -> String
        where
            T: std::string::ToString,
        {
            let mut input = String::new();
            self.print(message, settings);
            io::stdin()
                .read_line(&mut input)
                .expect("Error while getting input from operating system");
            input = String::from(input.trim());
            input
        }
    }

    pub enum Color {
        Clear,
        Black,
        Red,
        Green,
        Yellow,
        Blue,
        Magenta,
        Cyan,
        White,

        BrightBlack,
        BrightRed,
        BrightGreen,
        BrightYellow,
        BrightBlue,
        BrightMagenta,
        BrightCyan,
        BrightWhite,
    }

    impl Color {
        fn get_text_code(&self) -> &str {
            match self {
                Color::Clear => "\x1b[0m",
                Color::Black => "\x1b[30m",
                Color::Red => "\x1b[31m",
                Color::Green => "\x1b[32m",
                Color::Yellow => "\x1b[33m",
                Color::Blue => "\x1b[34m",
                Color::Magenta => "\x1b[35m",
                Color::Cyan => "\x1b[36m",
                Color::White => "\x1b[37m",

                Color::BrightBlack => "\x1b[90m",
                Color::BrightRed => "\x1b[91m",
                Color::BrightGreen => "\x1b[92m",
                Color::BrightYellow => "\x1b[93m",
                Color::BrightBlue => "\x1b[94m",
                Color::BrightMagenta => "\x1b[95m",
                Color::BrightCyan => "\x1b[96m",
                Color::BrightWhite => "\x1b[97m",
            }
        }

        fn get_bg_code(&self) -> &str {
            match self {
                Color::Clear => "",
                Color::Black => "\x1b[40m",
                Color::Red => "\x1b[41m",
                Color::Green => "\x1b[42m",
                Color::Yellow => "\x1b[43m",
                Color::Blue => "\x1b[44m",
                Color::Magenta => "\x1b[45m",
                Color::Cyan => "\x1b[46m",
                Color::White => "\x1b[47m",

                Color::BrightBlack => "\x1b[100m",
                Color::BrightRed => "\x1b[101m",
                Color::BrightGreen => "\x1b[102m",
                Color::BrightYellow => "\x1b[103m",
                Color::BrightBlue => "\x1b[104m",
                Color::BrightMagenta => "\x1b[105m",
                Color::BrightCyan => "\x1b[106m",
                Color::BrightWhite => "\x1b[107m",
            }
        }
    }

    pub struct Settings {
        color: Color,
        background_color: Color,
        speed: time::Duration,
    }

    impl Settings {
        // creates an instance of settings with default values
        pub fn new() -> Settings {
            Settings {
                color: Color::White,
                background_color: Color::Black,
                speed: time::Duration::from_millis(0),
            }
        }

        pub fn with_color(mut self, color: Color) -> Settings {
            self.color = color;
            self
        }

        pub fn with_background_color(mut self, color: Color) -> Settings {
            self.background_color = color;
            self
        }

        pub fn with_speed(mut self, speed: time::Duration) -> Settings {
            self.speed = speed;
            self
        }

        pub fn speed_very_slow(mut self) -> Settings {
            self.speed = time::Duration::from_millis(250);
            self
        }

        pub fn speed_slow(mut self) -> Settings {
            self.speed = time::Duration::from_millis(200);
            self
        }

        pub fn speed_medium(mut self) -> Settings {
            self.speed = time::Duration::from_millis(150);
            self
        }

        pub fn speed_fast(mut self) -> Settings {
            self.speed = time::Duration::from_millis(100);
            self
        }

        pub fn speed_very_fast(mut self) -> Settings {
            self.speed = time::Duration::from_millis(50);
            self
        }
    }
}

==> ConsoleEngine-0.0.3.crate: ConsoleEngine-0.0.3/src/lib.rs <==
pub mod console {
    use std::{io, thread, time};

    pub struct Console {}

    impl Console {
        pub fn new() -> Console {
            Console {}
        }

        pub fn print<T>(&self, message: T, settings: &Settings)
        where
            T: std::string::ToString,
        {
            for c in message.to_string().chars() {
                print!(
                    "{}{}{}{}",
                    settings.color.get_text_code(),
                    settings.background_color.get_bg_code(),
                    c,
                    Color::Clear.get_text_code()
                );
                io::Write::flush(&mut std::io::stdout()).unwrap();
                thread::sleep(settings.speed);
            }
        }

        pub fn print_line<T>(&self, message: T, settings: &Settings)
        where
            T: std::string::ToString,
        {
            for c in message.to_string().chars() {
                print!(
                    "{}{}{}{}",
                    settings.color.get_text_code(),
                    settings.background_color.get_bg_code(),
                    c,
                    Color::Clear.get_text_code()
                );
                io::Write::flush(&mut std::io::stdout()).unwrap();
                thread::sleep(settings.speed);
            }

            println!();
        }

        // gets input without new line from the console
        pub fn get_input(&self) -> String {
            let mut input = String::new();
            io::stdin()
                .read_line(&mut input)
                .expect("Error while getting input from operating system");
            input = String::from(input.trim());
            input
        }

        // gets input without new line from the console with custom message and settings
        pub fn get_custom_input<T>(&self, message: T, settings: &Settings) -> String
        where
            T: std::string::ToString,
        {
            let mut input = String::new();
            self.print(message, settings);
            io::stdin()
                .read_line(&mut input)
                .expect("Error while getting input from operating system");
            input = String::from(input.trim());
            input
        }
    }

    pub enum Color {
        Clear,
        Black,
        Red,
        Green,
        Yellow,
        Blue,
        Magenta,
        Cyan,
        White,

        BrightBlack,
        BrightRed,
        BrightGreen,
        BrightYellow,
        BrightBlue,
        BrightMagenta,
        BrightCyan,
        BrightWhite,
    }

    impl Color {
        fn get_text_code(&self) -> &str {
            match self {
                Color::Clear => "\x1b[0m",
                Color::Black => "\x1b[30m",
                Color::Red => "\x1b[31m",
                Color::Green => "\x1b[32m",
                Color::Yellow => "\x1b[33m",
                Color::Blue => "\x1b[34m",
                Color::Magenta => "\x1b[35m",
                Color::Cyan => "\x1b[36m",
                Color::White => "\x1b[37m",

                Color::BrightBlack => "\x1b[90m",
                Color::BrightRed => "\x1b[91m",
                Color::BrightGreen => "\x1b[92m",
                Color::BrightYellow => "\x1b[93m",
                Color::BrightBlue => "\x1b[94m",
                Color::BrightMagenta => "\x1b[95m",
                Color::BrightCyan => "\x1b[96m",
                Color::BrightWhite => "\x1b[97m",
            }
        }

        fn get_bg_code(&self) -> &str {
            match self {
                Color::Clear => "",
                Color::Black => "\x1b[40m",
                Color::Red => "\x1b[41m",
                Color::Green => "\x1b[42m",
                Color::Yellow => "\x1b[43m",
                Color::Blue => "\x1b[44m",
                Color::Magenta => "\x1b[45m",
                Color::Cyan => "\x1b[46m",
                Color::White => "\x1b[47m",

                Color::BrightBlack => "\x1b[100m",
                Color::BrightRed => "\x1b[101m",
                Color::BrightGreen => "\x1b[102m",
                Color::BrightYellow => "\x1b[103m",
                Color::BrightBlue => "\x1b[104m",
                Color::BrightMagenta => "\x1b[105m",
                Color::BrightCyan => "\x1b[106m",
                Color::BrightWhite => "\x1b[107m",
            }
        }
    }

    pub struct Settings {
        color: Color,
        background_color: Color,
        speed: time::Duration,
    }

    impl Settings {
        // creates an instance of settings with default values
        pub fn new() -> Settings {
            Settings {
                color: Color::White,
                background_color: Color::Black,
                speed: time::Duration::from_millis(0),
            }
        }

        pub fn with_color(mut self, color: Color) -> Settings {
            self.color = color;
            self
        }

        pub fn with_background_color(mut self, color: Color) -> Settings {
            self.background_color = color;
            self
        }

        pub fn with_speed(mut self, speed: time::Duration) -> Settings {
            self.speed = speed;
            self
        }

        pub fn speed_very_slow(mut self) -> Settings {
            self.speed = time::Duration::from_millis(250);
            self
        }

        pub fn speed_slow(mut self) -> Settings {
            self.speed = time::Duration::from_millis(200);
            self
        }

        pub fn speed_medium(mut self) -> Settings {
            self.speed = time::Duration::from_millis(150);
            self
        }

        pub fn speed_fast(mut self) -> Settings {
            self.speed = time::Duration::from_millis(100);
            self
        }

        pub fn speed_very_fast(mut self) -> Settings {
            self.speed = time::Duration::from_millis(50);
            self
        }
    }
}
